import { EventEmitter, Component, Input, Output, Pipe, Directive, ElementRef, HostListener, Renderer2, NgModule, Inject, LOCALE_ID, ViewChild, ChangeDetectionStrategy } from '@angular/core';
import { DatePipe, CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { trigger, transition, query, style, animate, state } from '@angular/animations';
import { Subject, ReplaySubject } from 'rxjs';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';
import { HttpErrorResponse } from '@angular/common/http';

class ButtonComponent {
    constructor() {
        this.clickButton = new EventEmitter();
    }
    get fa() {
        switch (this.icon) {
            case 'add':
            case 'new': return 'fas fa-plus';
            case 'save': return 'far fa-save';
            case 'edit': return 'far fa-edit';
            case 'back': return 'fas fa-chevron-left';
            case 'cancel': return 'fas fa-times';
            case 'delete': return 'far fa-trash-alt';
            case 'search': return 'fas fa-search';
            case 'clear':
            case 'clearselection': return 'fas fa-eraser';
            case 'export': return 'fas fa-file-download';
            default: return '';
        }
    }
    get internalClass() {
        if (this.class)
            return this.class;
        switch (this.icon) {
            case 'save':
            case 'search':
            case 'new': return 'btn btn-primary';
            case 'clearselection':
            case 'edit': return 'btn btn-tertiary';
            case 'back':
            case 'clear':
            case 'export':
            case 'add':
            case 'cancel': return 'btn btn-secondary';
            case 'delete': return 'btn btn-tertiary danger';
            default: return '';
        }
    }
    ngOnInit() {
    }
}
ButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-button',
                template: "<button [class]=\"internalClass\" (click)=\"clickButton.emit()\" [routerLink]=\"link\">\r\n    <i [class]=\"fa\" *ngIf=\"fa\"></i>\r\n    <span>{{label}}</span>\r\n</button>\r\n\r\n",
                styles: [""]
            },] }
];
ButtonComponent.ctorParameters = () => [];
ButtonComponent.propDecorators = {
    icon: [{ type: Input }],
    link: [{ type: Input }],
    label: [{ type: Input }],
    class: [{ type: Input }],
    clickButton: [{ type: Output }]
};

const fadeAnimation = trigger('fadeAnimation', [
    // The '* => *' will trigger the animation to change between any two states
    transition('* => *', [
        // The query function has three params.
        // First is the event, so this will apply on entering or when the element is added to the DOM.
        // Second is a list of styles or animations to apply.
        // Third we add a config object with optional set to true, this is to signal
        // angular that the animation may not apply as it may or may not be in the DOM.
        query(':enter', [style({ opacity: 0 })], { optional: true }),
        query(':leave', 
        // here we apply a style and use the animate function to apply the style over 0.3 seconds
        [style({ opacity: 1 }), animate('0.2s', style({ opacity: 0 }))], { optional: true }),
        query(':enter', [style({ opacity: 0 }), animate('0.2s', style({ opacity: 1 }))], { optional: true })
    ])
]);
const simpleFadeAnimation = trigger('simpleFadeAnimation', [
    // the "in" style determines the "resting" state of the element when it is visible.
    state('in', style({ opacity: 1 })),
    // fade in when created. this could also be written as transition('void => *')
    transition(':enter', [
        style({ opacity: 0 }),
        animate(200)
    ]),
    // fade out when destroyed. this could also be written as transition('void => *')
    transition(':leave', animate(200, style({ opacity: 0 })))
]);

class ModalComponent {
    constructor() { }
    ngOnInit() {
    }
    open() {
        this.show = true;
    }
    close() {
        this.show = false;
    }
}
ModalComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-modal',
                template: "<div *ngIf=\"show\" [@simpleFadeAnimation]=\"'in'\" class=\"fixed bottom-0 z-20 inset-x-0 px-4 pb-4 sm:inset-0 sm:flex sm:items-center sm:justify-center\">\r\n    <div class=\"fixed inset-0 transition-opacity\" (click)=\"close()\">\r\n        <div class=\"absolute inset-0 bg-neutral-500 opacity-75\"></div>\r\n    </div>\r\n\r\n    <div class=\"bg-white overflow-hidden rounded-lg shadow-xl transform transition-all sm:max-w-5xl sm:w-full\" role=\"dialog\" aria-modal=\"true\" aria-labelledby=\"modal-headline\">\r\n        <div class=\"bg-white pl-4 pt-5 pb-4 sm:pl-6 sm:pb-4\">\r\n            <ng-content select=\"[icon]\"></ng-content>\r\n            <div class=\"mt-3 text-center sm:mt-0 sm:ml-4 sm:text-left\">\r\n                <div class=\"modal-title\">{{title}}</div>\r\n\r\n                <div class=\"mt-2 text-sm leading-5 text-neutral-500 overflow-auto\">\r\n                    <div class=\"modal-body overflow-auto\">\r\n                        <ng-content select=\"[body]\"></ng-content>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\r\n\r\n        <div class=\"bg-neutral-100 p-4 py-3 sm:p-6 sm:flex sm:flex-row-reverse\">\r\n            <ng-content select=\"[foot]\"></ng-content>\r\n        </div>\r\n    </div>\r\n</div>\r\n",
                animations: [simpleFadeAnimation],
                styles: [".modal-body{max-height:75vh}"]
            },] }
];
ModalComponent.ctorParameters = () => [];
ModalComponent.propDecorators = {
    title: [{ type: Input }]
};

class DropdownComponent {
    constructor() {
        this.open = false;
    }
    ngOnInit() {
    }
}
DropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-dropdown',
                template: "<div class=\"relative\" (click)=\"open = !open\" (clickOutside)=\"open = false\">\r\n  <span *ngIf=\"label\" class=\"nav-item pointer py-3\" [class.active]=\"open\">{{label}}</span>\r\n  <div>\r\n      <ng-content select=\"[icon]\"></ng-content>\r\n  </div>\r\n  <div class=\"dropdown\" [class.hidden]=\"!open\">\r\n      <ng-content select=\"[options]\"></ng-content>\r\n  </div>\r\n</div>\r\n",
                styles: [""]
            },] }
];
DropdownComponent.ctorParameters = () => [];
DropdownComponent.propDecorators = {
    label: [{ type: Input }]
};

class AutocompleteComponent {
    constructor() {
        this.valueChange = new EventEmitter();
        this.items = [];
        this.search = new EventEmitter();
        this.limitToList = false;
        this.disabled = false;
        this.searchTerms = new Subject();
        this.open = false;
        this.selectedIdx = -1;
    }
    ngOnInit() {
        this.searchTerms.pipe(debounceTime(500), distinctUntilChanged()).subscribe(x => this.search.next(x));
    }
    searchValue() {
        this.searchTerms.next(this.value);
        this.open = true;
        this.selectedIdx = -1;
    }
    changeValue() {
        setTimeout(() => {
            if (this.limitToList && this.items.filter(x => x == this.value).length == 0)
                this.value = null;
            this.valueChange.emit(this.value);
            this.open = false;
        }, 500);
    }
    clickItem(item) {
        this.value = item;
    }
    keyup(event) {
        switch (event.code) {
            case 'ArrowDown':
                if (this.items.length > 0 && this.selectedIdx < this.items.length - 1)
                    this.selectedIdx++;
                break;
            case 'ArrowUp':
                if (this.items.length > 0 && this.selectedIdx > 0)
                    this.selectedIdx--;
                break;
            case 'Enter':
                this.value = this.items[this.selectedIdx];
                this.changeValue();
                break;
            default:
                this.searchValue();
                break;
        }
    }
}
AutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-autocomplete',
                template: "<div class=\"autocomplete\">\r\n  <input (keyup)=\"keyup($event)\" [(ngModel)]=\"value\" (change)=\"changeValue()\" type=\"text\" class=\"form-control\" #autocomplete [disabled]=\"disabled\">\r\n  <div *ngIf=\"open && items?.length > 0\" class=\"list\">\r\n      <div [class.active]=\"idx == selectedIdx\" class=\"list-item\" *ngFor=\"let item of items; let idx = index\" (click)=\"clickItem(item)\" [innerHTML]=\"item | highlight:value\"></div>\r\n  </div>\r\n</div>\r\n",
                styles: [""]
            },] }
];
AutocompleteComponent.ctorParameters = () => [];
AutocompleteComponent.propDecorators = {
    value: [{ type: Input }],
    valueChange: [{ type: Output }],
    items: [{ type: Input }],
    search: [{ type: Output }],
    limitToList: [{ type: Input }],
    disabled: [{ type: Input }]
};

class HighlightPipe {
    transform(value, term) {
        if (!term || !value)
            return value;
        term = this.removeDiacritics(term.toLowerCase());
        let idx = this.removeDiacritics(value.toLowerCase()).indexOf(term);
        if (idx == -1)
            return value;
        let start = value.substr(0, idx);
        let highlight = value.substr(idx, term.length);
        let end = value.substr(idx + term.length);
        return start + "<strong>" + highlight + "</strong>" + end;
    }
    removeDiacritics(term) {
        term = term.toString().toLowerCase();
        return term.normalize('NFD').replace(/[\u0300-\u036f]/g, '');
    }
}
HighlightPipe.decorators = [
    { type: Pipe, args: [{
                name: 'highlight'
            },] }
];

class PaginationComponent {
    constructor() {
        this.pageSize = 20;
        this.maxSize = 5;
        this.pageChange = new EventEmitter();
        this.pageChanged = new EventEmitter();
        this.pages = [];
    }
    get totalPages() {
        return Math.ceil(this.totalRecords / this.pageSize);
    }
    get firstRecord() {
        return 1 + ((this.page - 1) * this.pageSize);
    }
    get lastRecord() {
        let i = this.page * this.pageSize;
        if (i > this.totalRecords)
            i = this.totalRecords;
        return i;
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        setTimeout(() => this.updatePages());
    }
    ngOnChanges(changes) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        if (!((_a = changes.pageSize) === null || _a === void 0 ? void 0 : _a.firstChange) && ((_b = changes.pageSize) === null || _b === void 0 ? void 0 : _b.currentValue) != ((_c = changes.pageSize) === null || _c === void 0 ? void 0 : _c.previousValue))
            this.updatePages();
        if (!((_d = changes.totalRecords) === null || _d === void 0 ? void 0 : _d.firstChange) && ((_e = changes.totalRecords) === null || _e === void 0 ? void 0 : _e.currentValue) != ((_f = changes.totalRecords) === null || _f === void 0 ? void 0 : _f.previousValue))
            this.updatePages();
        if (!((_g = changes.page) === null || _g === void 0 ? void 0 : _g.firstChange) && ((_h = changes.page) === null || _h === void 0 ? void 0 : _h.currentValue) != ((_j = changes.page) === null || _j === void 0 ? void 0 : _j.previousValue))
            this.updatePages();
    }
    updatePages() {
        if (this.page > this.totalPages)
            this.page = this.totalPages;
        if (this.page <= 0)
            this.page = 1;
        let backward = Math.trunc(this.maxSize / 2);
        let forward = Math.round(this.maxSize / 2) - 1;
        let start = this.page - backward;
        let end = this.page + forward;
        if (this.totalPages <= this.maxSize) {
            start = 1;
            end = this.totalPages;
        }
        else {
            if (start <= 0) {
                end += 1 - start;
                start = 1;
            }
            if (end >= this.totalPages) {
                let i = end - this.totalPages;
                start -= i;
                end = this.totalPages;
            }
        }
        this.pages = [];
        for (let i = start; i <= end; i++)
            this.pages.push(i);
    }
    paginate(page) {
        this.page = page;
        this.pageChange.emit(page);
        this.pageChanged.emit(page);
    }
    goToFirst() {
        this.paginate(1);
        this.updatePages();
    }
    canGoFirst() {
        return this.page != 1;
    }
    goToLast() {
        this.paginate(this.totalPages);
        this.updatePages();
    }
    canGoLast() {
        return this.page != this.totalPages && this.totalPages > 0;
    }
    goToPrevious() {
        if (this.page > 1)
            this.paginate(this.page - 1);
        this.updatePages();
    }
    canGoPrevious() {
        return this.page > 1;
    }
    goToNext() {
        if (this.page < this.totalPages)
            this.paginate(this.page + 1);
        this.updatePages();
    }
    canGoNext() {
        return this.page < this.totalPages;
    }
}
PaginationComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-pagination',
                template: "<div class=\"flex justify-between my-2\">\r\n  <div class=\"subtitle pt-5 pl-7\" *ngIf=\"totalRecords > 0\">\r\n      <span i18n=\"@@MostrandoRegistros\">Mostrando los registros</span><span class=\"mx-1\">{{firstRecord}}</span> <span i18n=\"@@A\">a</span> <span class=\"mx-1\">{{lastRecord}}</span>\r\n      <span i18n=\"@@DeTotalDe\">de un total de</span><span class=\"ml-1\">{{totalRecords}}</span>\r\n  </div>\r\n  <div *ngIf=\"totalRecords == 0\" class=\"subtitle pt-5 pl-7\">\r\n      <span i18n=\"@@NoExistenRegistros\">No existen registros</span>\r\n  </div>\r\n  <div class=\"paginate\">\r\n      <span class=\"relative z-0 inline-flex shadow-sm\">\r\n          <button *ngIf=\"canGoFirst()\" (click)=\"goToFirst()\" type=\"button\" class=\"first\">\r\n              <span i18n=\"@@Primero\">Primero</span>\r\n          </button>\r\n          <button *ngIf=\"canGoPrevious()\" (click)=\"goToPrevious()\" type=\"button\" class=\"page\">\r\n              <svg class=\"h-5 w-5\" fill=\"currentColor\" viewBox=\"0 0 20 20\">\r\n                  <path fill-rule=\"evenodd\" d=\"M12.707 5.293a1 1 0 010 1.414L9.414 10l3.293 3.293a1 1 0 01-1.414 1.414l-4-4a1 1 0 010-1.414l4-4a1 1 0 011.414 0z\" clip-rule=\"evenodd\" />\r\n              </svg>\r\n          </button>\r\n          <button (click)=\"paginate(item)\" [class.active]=\"page == item\" *ngFor=\"let item of pages\" type=\"button\" class=\"page\">\r\n              {{item}}\r\n          </button>\r\n          <button *ngIf=\"canGoNext()\" (click)=\"goToNext()\" type=\"button\" class=\"page\">\r\n              <svg class=\"h-5 w-5\" fill=\"currentColor\" viewBox=\"0 0 20 20\">\r\n                  <path fill-rule=\"evenodd\" d=\"M7.293 14.707a1 1 0 010-1.414L10.586 10 7.293 6.707a1 1 0 011.414-1.414l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414 0z\" clip-rule=\"evenodd\" />\r\n              </svg>\r\n          </button>\r\n          <button *ngIf=\"canGoLast()\" (click)=\"goToLast()\" type=\"button\" class=\"last\">\r\n              <span i18n=\"@@Ultimo\">\u00DAltimo</span>\r\n          </button>\r\n      </span>\r\n  </div>\r\n</div>\r\n",
                styles: [""]
            },] }
];
PaginationComponent.ctorParameters = () => [];
PaginationComponent.propDecorators = {
    totalRecords: [{ type: Input }],
    pageSize: [{ type: Input }],
    page: [{ type: Input }],
    maxSize: [{ type: Input }],
    pageChange: [{ type: Output }],
    pageChanged: [{ type: Output }]
};

class SearchboxComponent {
    constructor() {
        this.search = new EventEmitter();
        this.searchTerms = new Subject();
        this.open = false;
    }
    ngOnInit() {
        this.searchTerms.pipe(debounceTime(500), distinctUntilChanged()).subscribe(x => this.search.next(x));
    }
    searchChangeValue(term) {
        this.searchTerms.next(term);
    }
}
SearchboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-searchbox',
                template: "<div class=\"input-group\">\r\n  <span class=\"input-group-icon\">\r\n      <svg fill=\"none\" viewBox=\"0 0 24 24\">\r\n          <path d=\"M3 4a1 1 0 011-1h16a1 1 0 011 1v2.586a1 1 0 01-.293.707l-6.414 6.414a1 1 0 00-.293.707V17l-4 4v-6.586a1 1 0 00-.293-.707L3.293 7.293A1 1 0 013 6.586V4z\"></path>\r\n      </svg>\r\n  </span>\r\n  <input (keyup)=\"searchChangeValue(searchBox.value)\" type=\"text\" class=\"form-filter\" #searchBox>\r\n</div>\r\n\r\n",
                styles: [""]
            },] }
];
SearchboxComponent.ctorParameters = () => [];
SearchboxComponent.propDecorators = {
    search: [{ type: Output }]
};

class SelectComponent {
    constructor() {
        this.tipo = 'number';
        this.permitirVacio = false;
        this.deshabilitar = false;
        this.selectedItemChange = new EventEmitter();
        this.change = new EventEmitter();
    }
    ngOnInit() {
    }
    doChange(item) {
        this.selectedItemChange.emit(item);
        this.change.emit(item);
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-select',
                template: "<div class=\"relative\">\r\n  <select *ngIf=\"tipo == 'number'\" class=\"form-control\" [(ngModel)]=\"selectedItem\" (change)=\"doChange(selectedItem)\" [disabled]=\"deshabilitar\">\r\n      <option *ngIf=\"permitirVacio\" [ngValue]=\"null\"></option>\r\n      <option *ngFor=\"let item of items\" [value]=\"item.keyInt\">{{item.value | remove:remove}}</option>\r\n  </select>\r\n\r\n  <select *ngIf=\"tipo == 'guid'\" class=\"form-control\" [(ngModel)]=\"selectedItem\" (change)=\"doChange(selectedItem)\" [disabled]=\"deshabilitar\">\r\n      <option *ngIf=\"permitirVacio\" [ngValue]=\"null\"></option>\r\n      <option *ngFor=\"let item of items\" [value]=\"item.keyGuid\">{{item.value | remove:remove}}</option>\r\n  </select>\r\n\r\n  <select *ngIf=\"tipo == 'string'\" class=\"form-control\" [(ngModel)]=\"selectedItem\" (change)=\"doChange(selectedItem)\" [disabled]=\"deshabilitar\">\r\n    <option *ngIf=\"permitirVacio\" [ngValue]=\"null\"></option>\r\n    <option *ngFor=\"let item of items\" [value]=\"item.key\">{{item.value | remove:remove}}</option>\r\n</select>\r\n\r\n  <div class=\"pointer-events-none absolute inset-y-0 right-0 flex items-center px-2 text-neutral-700\">\r\n      <svg class=\"fill-current h-4 w-4\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 20 20\">\r\n          <path d=\"M9.293 12.95l.707.707L15.657 8l-1.414-1.414L10 10.828 5.757 6.586 4.343 8z\" />\r\n      </svg>\r\n  </div>\r\n</div>\r\n",
                styles: [""]
            },] }
];
SelectComponent.ctorParameters = () => [];
SelectComponent.propDecorators = {
    items: [{ type: Input }],
    tipo: [{ type: Input }],
    remove: [{ type: Input }],
    permitirVacio: [{ type: Input }],
    deshabilitar: [{ type: Input }],
    selectedItem: [{ type: Input }],
    selectedItemChange: [{ type: Output }],
    change: [{ type: Output }]
};

class RemovePipe {
    transform(value, until) {
        if (!value || !until)
            return value;
        let idx = value.indexOf(until);
        if (idx == -1)
            return value;
        return value.substr(idx + 1);
    }
}
RemovePipe.decorators = [
    { type: Pipe, args: [{
                name: 'remove'
            },] }
];

class ValidationSummaryComponent {
    constructor() {
        this.mensajes = [];
        this.keys = [];
        this.keysChange = new EventEmitter();
    }
    set errors(error) {
        this.mensajes = [];
        this.keys = [];
        if (!error) {
            this.keysChange.emit(this.keys);
            return;
        }
        window.scrollTo(0, 0);
        if (error instanceof HttpErrorResponse) {
            if (error.status && error.status == 0) {
                alert('Cannot connect to the server');
                this.keysChange.emit(this.keys);
                return;
            }
            if (error.status && error.status == 403) {
                this.keysChange.emit(this.keys);
                return;
            }
            if (error.status && error.status >= 400 && error.status < 500) {
                if (!error.error.detail)
                    this.mensajes.push(error.error.error);
                else
                    for (let item of error.error.detail) {
                        this.mensajes.push(item.value);
                        this.keys.push(item.key);
                    }
                this.keysChange.emit(this.keys);
                return;
            }
            if (error.status && error.status >= 500) {
                if (error.error.error)
                    this.mensajes.push('Internal server error: ' + error.error.error);
                else
                    this.mensajes.push('Internal server error: ' + error.statusText);
                this.keysChange.emit(this.keys);
                return;
            }
            this.keysChange.emit(this.keys);
            return;
        }
        else if (error.detail) {
            this.mensajes = [];
            for (let item of error.detail) {
                this.mensajes.push(item.value);
                this.keys.push(item.key);
            }
        }
        if (error.error.error)
            this.mensajes.push(error.error.error);
        else if (error.statusText)
            this.mensajes.push(error.statusText);
        this.keysChange.emit(this.keys);
    }
}
ValidationSummaryComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-validation-summary',
                template: "<div class=\"alert alert-danger mb-5\" *ngIf=\"mensajes && mensajes.length > 0\">\r\n    <div class=\"flex\">\r\n        <svg fill=\"none\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-width=\"2\" viewBox=\"0 0 24 24\">\r\n            <path d=\"M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z\"></path>\r\n        </svg>\r\n        <span class=\"font-bold\" i18n=\"@@SeHanProducidoErrores\">Se han producido los errores siguientes</span>\r\n    </div>\r\n    <ul class=\"mt-3 pl-15 font-semibold\">\r\n        <li *ngFor=\"let mensaje of mensajes\">\r\n            {{mensaje}}\r\n        </li>\r\n    </ul>\r\n</div>\r\n",
                styles: [""]
            },] }
];
ValidationSummaryComponent.propDecorators = {
    keysChange: [{ type: Output }],
    errors: [{ type: Input }]
};

class ClickOutsideDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.clickOutside = new EventEmitter();
    }
    onClick(target) {
        const clickedInside = this.elementRef.nativeElement.contains(target);
        if (!clickedInside) {
            this.clickOutside.emit();
        }
    }
}
ClickOutsideDirective.decorators = [
    { type: Directive, args: [{
                selector: '[clickOutside]',
            },] }
];
ClickOutsideDirective.ctorParameters = () => [
    { type: ElementRef }
];
ClickOutsideDirective.propDecorators = {
    clickOutside: [{ type: Output }],
    onClick: [{ type: HostListener, args: ['document:click', ['$event.target'],] }]
};

class ValidationDirective {
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
    }
    ngAfterViewInit() {
        this.appValidation.keysChange.subscribe((keys) => {
            this.renderer.removeClass(this.el.nativeElement, 'is-invalid');
            let existe = (this.el.nativeElement.name && keys.filter(x => x.toLowerCase() == this.el.nativeElement.name.toLowerCase()))
                || (this.el.nativeElement.id && keys.filter(x => x.toLowerCase() == this.el.nativeElement.id.toLowerCase()));
            if (existe.length > 0)
                this.renderer.addClass(this.el.nativeElement, 'is-invalid');
        });
    }
}
ValidationDirective.decorators = [
    { type: Directive, args: [{
                selector: '[twValidation]'
            },] }
];
ValidationDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
ValidationDirective.propDecorators = {
    appValidation: [{ type: Input }]
};

class TailwindDirectivesModule {
}
TailwindDirectivesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ClickOutsideDirective, ValidationDirective],
                exports: [
                    ClickOutsideDirective,
                    ValidationDirective
                ]
            },] }
];

class CalendarComponent {
    constructor(locale) {
        this.locale = locale;
        this.showWeekend = false;
        this.events = [];
        this.clickEvent = new EventEmitter();
        this.clickDay = new EventEmitter();
        this.loadEvents = new EventEmitter();
        this.view = 'month';
    }
    ngOnInit() { }
    clickDayMonth(day) {
        let fecha = new Date(day.year, day.month, day.day);
        this.view = 'week';
        this.weekCalendar.goTo(fecha);
    }
    clickDayWeek(day) {
        let fecha = new Date(day.year, day.month, day.day);
        this.clickDay.emit(fecha);
    }
    changeView(view) {
        this.view = view;
        switch (view) {
            case 'week':
                this.weekCalendar.getDates();
                break;
            case 'month':
                this.monthCalendar.getDates();
                break;
        }
    }
    refresh(e) {
        if (e.view == this.view && e.fechaIni && e.fechaFin)
            this.loadEvents.emit(e);
    }
    goTo(date) {
        switch (this.view) {
            case 'week':
                this.weekCalendar.goTo(date);
                break;
            case 'month':
                this.monthCalendar.goTo(date);
                break;
        }
    }
}
CalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-calendar',
                template: " <div id=\"calendar\">\r\n    <tw-calendar-month #monthCalendar [display]=\"view == 'month'\" (clickEvent)=\"clickEvent.emit($event)\" (loadEvents)=\"refresh($event)\" (changeView)=\"changeView($event)\" (clickDay)=\"clickDayMonth($event)\" [showWeekend]=\"showWeekend\" [lang]=\"locale\" [events]=\"events\"></tw-calendar-month>\r\n\r\n    <tw-calendar-week #weekCalendar [display]=\"view == 'week'\" (clickEvent)=\"clickEvent.emit($event)\" (loadEvents)=\"refresh($event)\" (changeView)=\"changeView($event)\" (clickDay)=\"clickDayWeek($event)\" [showWeekend]=\"showWeekend\" [lang]=\"locale\" [events]=\"events\"></tw-calendar-week>\r\n</div>\r\n",
                styles: ["#calendar{padding:10px}"]
            },] }
];
CalendarComponent.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [LOCALE_ID,] }] }
];
CalendarComponent.propDecorators = {
    showWeekend: [{ type: Input }],
    events: [{ type: Input }],
    clickEvent: [{ type: Output }],
    clickDay: [{ type: Output }],
    loadEvents: [{ type: Output }],
    monthCalendar: [{ type: ViewChild, args: ['monthCalendar',] }],
    weekCalendar: [{ type: ViewChild, args: ['weekCalendar',] }]
};

class CalendarWeekDTO {
}
class CalendarDayDTO {
    constructor() {
        this.events = [];
    }
}
class CalendarEventDTO {
    get time() {
        return this.date.getHours().toString().padStart(2, '0') + ':' + this.date.getMinutes().toString().padStart(2, '0');
    }
}

class CalendarMonthComponent {
    constructor() {
        this.loadEvents = new EventEmitter();
        this.changeView = new EventEmitter();
        this.clickEvent = new EventEmitter();
        this.clickDay = new EventEmitter();
        this._events = [];
        this.fecha = new Date();
        this.weeks = [];
        this.months = ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre',
            'January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
        this.days = ['lun', 'mar', 'mié', 'jue', 'vie', 'sáb', 'dom',
            'mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun'];
        this.month = 0;
        this.langNumber = 0;
        this.month = this.fecha.getMonth();
        this.year = this.fecha.getFullYear();
    }
    set events(value) {
        this._events = value;
        this.refresh();
    }
    ngOnInit() { }
    ngAfterContentInit() {
        this.month = this.fecha.getMonth();
        this.year = this.fecha.getFullYear();
        if (this.lang.startsWith('en'))
            this.langNumber = 1;
        setTimeout(() => this.getDates());
    }
    back() {
        if (this.month == 0) {
            this.year--;
            this.month = 11;
        }
        else
            this.month--;
        this.fecha = new Date(this.year, this.month, 1);
        this.getDates();
    }
    next() {
        if (this.month == 11) {
            this.month = 0;
            this.year++;
        }
        else
            this.month++;
        this.fecha = new Date(this.year, this.month, 1);
        this.getDates();
    }
    getDates() {
        this.weeks = [];
        let year = this.year;
        let month = this.month;
        let day = 1;
        let fecha = new Date(year, month, day);
        while (fecha.getDay() != 1) {
            fecha.setDate(fecha.getDate() - 1);
        }
        let fechaIni = new Date(fecha.getFullYear(), fecha.getMonth(), fecha.getDate());
        let fechaFin = new Date(fecha.getFullYear(), fecha.getMonth(), fecha.getDate());
        fechaFin.setDate(fechaIni.getDate() + 6 * 7);
        // Fechas
        for (let w = 0; w < 6; w++) {
            let week = new CalendarWeekDTO();
            week.days = [];
            this.weeks.push(week);
            for (let d = 0; d <= 6; d++) {
                let calDay = new CalendarDayDTO();
                calDay.day = fecha.getDate();
                calDay.month = fecha.getMonth();
                calDay.year = fecha.getFullYear();
                calDay.today = fecha.getDate() == new Date().getDate() &&
                    fecha.getMonth() == new Date().getMonth() &&
                    fecha.getFullYear() == new Date().getFullYear();
                calDay.out = fecha.getMonth() != this.month;
                if ((fecha.getDay() != 0 && fecha.getDay() != 6) || this.showWeekend)
                    week.days.push(calDay);
                fecha.setDate(fecha.getDate() + 1);
            }
        }
        // Recarga de eventos
        this.loadEvents.emit({ view: 'month', fechaIni, fechaFin });
    }
    refresh() {
        if (!this._events)
            this._events = [];
        for (let week of this.weeks) {
            for (let calDay of week.days) {
                calDay.events = [];
                for (let event of this._events) {
                    if (calDay.day == event.date.getDate() &&
                        calDay.month == event.date.getMonth() &&
                        calDay.year == event.date.getFullYear())
                        calDay.events.push(event);
                }
            }
        }
    }
    clickDia(day) {
        this.clickDay.emit(day);
    }
    goTo(date) {
        this.fecha = date;
        this.month = this.fecha.getMonth();
        this.year = this.fecha.getFullYear();
        this.getDates();
    }
}
CalendarMonthComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-calendar-month',
                template: "<div [class.hidden]=\"!display\">\r\n    <div class=\"mx-4 flex justify-between\">\r\n        <div>\r\n            <button class=\"btn-calendar rounded-l-lg\" (click)=\"back()\"><i class=\"fas fa-caret-left\"></i></button>\r\n            <button class=\"btn-calendar rounded-r-lg\" (click)=\"next()\"><i class=\"fas fa-caret-right\"></i></button>\r\n        </div>\r\n        <h2 class=\"text-center\">{{months[month + langNumber * 12]}} {{year}}</h2>\r\n        <div>\r\n            <button class=\"btn-calendar active rounded-l-lg\" (click)=\"changeView.emit('month')\">Mes</button>\r\n            <button class=\"btn-calendar rounded-r-lg\" (click)=\"changeView.emit('week')\">Semana</button>\r\n        </div>\r\n    </div>\r\n\r\n    <div class=\"table-container\">\r\n        <table class=\"table-calendar\">\r\n            <tr class=\"table-calendar-header font-bold text-center\">\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[0 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[1 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[2 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[3 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[4 + langNumber * 7]}}</td>\r\n                <td [class.w-c7]=\"showWeekend\" *ngIf=\"showWeekend\">{{days[5 + langNumber * 7]}}</td>\r\n                <td [class.w-c7]=\"showWeekend\" *ngIf=\"showWeekend\">{{days[6 + langNumber * 7]}}</td>\r\n            </tr>\r\n            <tr class=\"week\" *ngFor=\"let week of weeks\">\r\n                <td *ngFor=\"let day of week.days\" [class.bg-gray]=\"day.out\" [class.bg-today]=\"day.today\" class=\"cell\" (click)=\"clickDia(day)\">\r\n                    <div class=\"day\">{{day.day}}</div>\r\n\r\n                    <div *ngFor=\"let event of day.events\" class=\"pointer evento {{event.class}}\" (click)=\"$event.stopPropagation();clickEvent.emit(event)\">\r\n                        <span class=\"hora\">{{event.time}}</span>\r\n                        <span class=\"nombre\">{{event.title}}</span>\r\n                        <span class=\"comentario\">{{event.comments}}</span>\r\n                    </div>\r\n                </td>\r\n            </tr>\r\n        </table>\r\n    </div>\r\n</div>\r\n",
                styles: ["h2{font-size:2rem}table{min-width:100%}table,td,th{padding:10px;vertical-align:top}.pointer{cursor:pointer}.cell{height:120px}.day{text-align:right}.w-c7{width:14.286%!important}.w-c5{width:20%!important}.evento{border-radius:5px;margin:2px 0;padding:5px}.hora{font-weight:700}.comentario,.hora,.nombre{margin-right:5px}"]
            },] }
];
CalendarMonthComponent.ctorParameters = () => [];
CalendarMonthComponent.propDecorators = {
    lang: [{ type: Input }],
    showWeekend: [{ type: Input }],
    display: [{ type: Input }],
    loadEvents: [{ type: Output }],
    changeView: [{ type: Output }],
    clickEvent: [{ type: Output }],
    clickDay: [{ type: Output }],
    events: [{ type: Input }]
};

class CalendarWeekComponent {
    constructor() {
        this.loadEvents = new EventEmitter();
        this.changeView = new EventEmitter();
        this.clickEvent = new EventEmitter();
        this.clickDay = new EventEmitter();
        this.fechaIni = new Date();
        this.fechaFin = new Date();
        this._events = [];
        this.fecha = new Date();
        this.daysWeek = [];
        this.days = ['lun', 'mar', 'mié', 'jue', 'vie', 'sáb', 'dom',
            'mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun'];
        this.langNumber = 0;
    }
    set events(value) {
        this._events = value;
        this.refresh();
    }
    ngOnInit() { }
    ngAfterContentInit() {
        if (this.lang.startsWith('en'))
            this.langNumber = 1;
        setTimeout(() => this.getDates());
    }
    back() {
        this.fecha.setDate(this.fecha.getDate() - 7);
        this.getDates();
    }
    next() {
        this.fecha.setDate(this.fecha.getDate() + 7);
        this.getDates();
    }
    getDates() {
        this.daysWeek = [];
        let year = this.fecha.getFullYear();
        let month = this.fecha.getMonth();
        let day = this.fecha.getDate();
        let fecha = new Date(year, month, day);
        while (fecha.getDay() != 1) {
            fecha.setDate(fecha.getDate() - 1);
        }
        this.fechaIni = new Date(fecha.getFullYear(), fecha.getMonth(), fecha.getDate());
        this.fechaFin = new Date(fecha.getFullYear(), fecha.getMonth(), fecha.getDate());
        this.fechaFin.setDate(this.fechaIni.getDate() + 7);
        // Fechas
        for (let d = 0; d <= 6; d++) {
            let calDay = new CalendarDayDTO();
            calDay.day = fecha.getDate();
            calDay.month = fecha.getMonth();
            calDay.year = fecha.getFullYear();
            calDay.today = fecha.getDate() == new Date().getDate() &&
                fecha.getMonth() == new Date().getMonth() &&
                fecha.getFullYear() == new Date().getFullYear();
            if ((fecha.getDay() != 0 && fecha.getDay() != 6) || this.showWeekend)
                this.daysWeek.push(calDay);
            fecha.setDate(fecha.getDate() + 1);
        }
        // Recarga de eventos
        this.loadEvents.emit({ view: 'week', fechaIni: this.fechaIni, fechaFin: this.fechaFin });
    }
    refresh() {
        if (!this._events)
            this._events = [];
        for (let calDay of this.daysWeek) {
            calDay.events = [];
            for (let event of this._events) {
                if (calDay.day == event.date.getDate() &&
                    calDay.month == event.date.getMonth() &&
                    calDay.year == event.date.getFullYear())
                    calDay.events.push(event);
            }
        }
    }
    clickDia(day) {
        this.clickDay.emit(day);
    }
    goTo(date) {
        this.fecha = date;
        this.getDates();
    }
}
CalendarWeekComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-calendar-week',
                template: "<div [class.hidden]=\"!display\">\r\n    <div class=\"mx-4 flex justify-between\">\r\n        <div>\r\n            <button class=\"btn-calendar rounded-l-lg\" (click)=\"back()\"><i class=\"fas fa-caret-left\"></i></button>\r\n            <button class=\"btn-calendar rounded-r-lg\" (click)=\"next()\"><i class=\"fas fa-caret-right\"></i></button>\r\n        </div>\r\n        <h2 class=\"text-center\">{{fechaIni | formatDate}} - {{fechaFin | formatDate}}</h2>\r\n        <div>\r\n            <button class=\"btn-calendar rounded-l-lg\" (click)=\"changeView.emit('month')\">Mes</button>\r\n            <button class=\"btn-calendar active rounded-r-lg\" (click)=\"changeView.emit('week')\">Semana</button>\r\n        </div>\r\n    </div>\r\n\r\n    <div class=\"table-container\">\r\n        <table class=\"table-calendar\">\r\n            <tr class=\"table-calendar-header font-bold text-center\">\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[0 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[1 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[2 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[3 + langNumber * 7]}}</td>\r\n                <td [class.w-c5]=\"!showWeekend\" [class.w-c7]=\"showWeekend\">{{days[4 + langNumber * 7]}}</td>\r\n                <td [class.w-c7]=\"showWeekend\" *ngIf=\"showWeekend\">{{days[5 + langNumber * 7]}}</td>\r\n                <td [class.w-c7]=\"showWeekend\" *ngIf=\"showWeekend\">{{days[6 + langNumber * 7]}}</td>\r\n            </tr>\r\n            <tr>\r\n                <td *ngFor=\"let day of daysWeek\" [class.bg-gray]=\"day.out\" [class.bg-today]=\"day.today\" class=\"cell\" (click)=\"clickDia(day)\">\r\n                    <div class=\"day\">{{day.day}}</div>\r\n\r\n                    <div *ngFor=\"let event of day.events\" class=\"pointer evento {{event.class}}\" (click)=\"$event.stopPropagation();clickEvent.emit(event)\">\r\n                        <span class=\"hora\">{{event.time}}</span>\r\n                        <span class=\"nombre\">{{event.title}}</span>\r\n                        <span class=\"comentario\">{{event.comments}}</span>\r\n                    </div>\r\n                </td>\r\n            </tr>\r\n        </table>\r\n    </div>\r\n</div>\r\n",
                styles: ["h2{font-size:2rem}table{min-width:100%}table,td,th{padding:10px;vertical-align:top}.pointer{cursor:pointer}.cell{height:500px}.day{text-align:right}.w-c7{width:14.286%!important}.w-c5{width:20%!important}.evento{border-radius:5px;margin:2px 0;padding:5px}.hora{font-weight:700}.comentario,.hora,.nombre{margin-right:5px}"]
            },] }
];
CalendarWeekComponent.ctorParameters = () => [];
CalendarWeekComponent.propDecorators = {
    lang: [{ type: Input }],
    showWeekend: [{ type: Input }],
    display: [{ type: Input }],
    loadEvents: [{ type: Output }],
    changeView: [{ type: Output }],
    clickEvent: [{ type: Output }],
    clickDay: [{ type: Output }],
    events: [{ type: Input }]
};

class FormatDatePipe {
    constructor(locale) {
        this.locale = locale;
    }
    transform(date, tipo = 'fecha') {
        if (!date)
            return '';
        let d = new Date(date);
        let formato = '';
        if (tipo.toLowerCase() == 'hora')
            formato = 'HH:mm';
        if (tipo.toLowerCase() == 'fecha')
            formato = 'dd/MM/yyyy';
        if (tipo.toLowerCase() == 'fechahora')
            formato = 'dd/MM/yyyy HH:mm';
        if (tipo.toLowerCase() == 'fechadia')
            formato = 'EEEE, dd/MM/yyyy';
        if (this.locale === 'en' && tipo.toLowerCase() == 'fecha')
            formato = 'MM/dd/yyyy';
        if (this.locale === 'en' && tipo.toLowerCase() == 'fechahora')
            formato = 'MM/dd/yyyy HH:mm';
        let datePipe = new DatePipe(this.locale);
        return datePipe.transform(date, formato);
    }
}
FormatDatePipe.decorators = [
    { type: Pipe, args: [{
                name: 'formatDate'
            },] }
];
FormatDatePipe.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [LOCALE_ID,] }] }
];

class SharedModule {
}
SharedModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FormatDatePipe],
                imports: [
                    CommonModule
                ],
                exports: [
                    FormatDatePipe
                ]
            },] }
];

class DropdownButtonComponent {
    constructor() {
        this.left = true;
        this.open = false;
    }
    ngOnInit() {
    }
}
DropdownButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-dropdown-button',
                template: "<div class=\"relative dropdown-button\" [class]=\"class\"  (click)=\"open = !open\" (clickOutside)=\"open = false\">\n    <span *ngIf=\"label\" class=\"dropdown-button-title pointer\" [class.active]=\"open\">{{label}}</span>\n    <div class=\"dropdown-button-items\" [class.hidden]=\"!open\">\n        <ng-content></ng-content>\n    </div>\n</div>\n",
                styles: [""]
            },] }
];
DropdownButtonComponent.ctorParameters = () => [];
DropdownButtonComponent.propDecorators = {
    label: [{ type: Input }],
    left: [{ type: Input }],
    right: [{ type: Input }],
    class: [{ type: Input }]
};

class TailwindComponentsModule {
}
TailwindComponentsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ButtonComponent,
                    DropdownComponent,
                    AutocompleteComponent,
                    ModalComponent,
                    PaginationComponent,
                    SearchboxComponent,
                    SelectComponent,
                    HighlightPipe,
                    RemovePipe,
                    ValidationSummaryComponent,
                    CalendarComponent,
                    CalendarMonthComponent,
                    CalendarWeekComponent,
                    DropdownButtonComponent
                ],
                imports: [
                    CommonModule,
                    TailwindDirectivesModule,
                    FormsModule,
                    RouterModule,
                    SharedModule
                ],
                exports: [
                    ButtonComponent,
                    DropdownComponent,
                    AutocompleteComponent,
                    ModalComponent,
                    PaginationComponent,
                    SearchboxComponent,
                    SelectComponent,
                    ValidationSummaryComponent,
                    CalendarComponent,
                    DropdownButtonComponent
                ]
            },] }
];

class SorterComponent {
    constructor() { }
    ngOnInit() {
    }
}
SorterComponent.decorators = [
    { type: Component, args: [{
                selector: 'tw-sorter',
                template: "<ng-container *ngIf=\"column && sortField\">\r\n    <div class=\"flex\" [class.text-teal-500]=\"sortField.toLowerCase() == column.toLowerCase()\">\r\n        <div>\r\n            <ng-content></ng-content>\r\n        </div>\r\n        <span *ngIf=\"sortField.toLowerCase() == column.toLowerCase() && sortOrder == 'asc'\">\r\n            <svg fill=\"none\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-width=\"2\" viewBox=\"0 0 24 24\" class=\"w-4 h-4 ml-1\"><path d=\"M5 15l7-7 7 7\"></path></svg>\r\n        </span>\r\n        <span *ngIf=\"sortField.toLowerCase() == column.toLowerCase() && sortOrder == 'desc'\">\r\n            <svg fill=\"none\" stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-width=\"2\" viewBox=\"0 0 24 24\" class=\"w-4 h-4 ml-1\"><path d=\"M19 9l-7 7-7-7\"></path></svg>\r\n        </span>\r\n    </div>\r\n\r\n</ng-container>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];
SorterComponent.ctorParameters = () => [];
SorterComponent.propDecorators = {
    column: [{ type: Input }],
    sortField: [{ type: Input }],
    sortOrder: [{ type: Input }]
};

class TailwindTablesModule {
}
TailwindTablesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SorterComponent],
                imports: [
                    CommonModule
                ],
                exports: [
                    SorterComponent
                ]
            },] }
];

class PaginationParameters {
    constructor() {
        this.page = 1;
        this.rows = 20;
    }
}

class TableSelect {
    constructor(key) {
        this.seleccion = [];
        this.idxUltimoItem = 0;
        this.key = key;
    }
    get items() {
        return this.seleccion;
    }
    set items(value) {
        this.seleccion = value;
    }
    selecciona(item, allItems, event) {
        let idx = allItems.findIndex(x => x == item);
        if (event.shiftKey) {
            if (this.idxUltimoItem == idx)
                return;
            let seleccionar = !this.contains(item);
            if (this.idxUltimoItem < idx) {
                for (let i = this.idxUltimoItem; i <= idx; i++) {
                    // Selección hacia abajo
                    if (seleccionar)
                        this.set(allItems[i]);
                    // Deselección hacia abajo
                    if (!seleccionar)
                        this.unset(allItems[i]);
                }
            }
            if (this.idxUltimoItem > idx) {
                for (let i = idx; i <= this.idxUltimoItem; i++) {
                    // Selección hacia arriba
                    if (seleccionar)
                        this.set(allItems[i]);
                    // Deselección hacia arriba
                    if (!seleccionar)
                        this.unset(allItems[i]);
                }
                if (!seleccionar)
                    this.set(allItems[idx]);
            }
        }
        else
            this.toggle(item);
        this.idxUltimoItem = idx;
    }
    contains(item) {
        return this.seleccion.findIndex(x => x[this.key] == item[this.key]) > -1;
    }
    reset() {
        this.seleccion = [];
        this.idxUltimoItem = 0;
    }
    toggle(item) {
        let idx = this.seleccion.findIndex(x => x[this.key] == item[this.key]);
        if (idx == -1)
            this.set(item);
        else
            this.unset(item);
    }
    set(item) {
        let idx = this.seleccion.findIndex(x => x[this.key] == item[this.key]);
        if (idx == -1)
            this.seleccion.push(item);
    }
    unset(item) {
        let idx = this.seleccion.findIndex(x => x[this.key] == item[this.key]);
        if (idx > -1)
            this.seleccion.splice(idx, 1);
    }
}

class TableSort {
    constructor(criterios) {
        this.sort$ = new ReplaySubject(1);
        this.criterios = criterios;
    }
    sort(field) {
        if (this.criterios.sortField == field) {
            this.criterios.sortOrder = this.criterios.sortOrder == 'asc' ? 'desc' : 'asc';
        }
        else {
            this.criterios.sortField = field;
            this.criterios.sortOrder = 'asc';
        }
        this.sort$.next(this.criterios);
    }
}

/*
 * Public API Surface of tailwind-lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AutocompleteComponent, ButtonComponent, CalendarComponent, CalendarDayDTO, CalendarEventDTO, CalendarWeekDTO, ClickOutsideDirective, DropdownButtonComponent, DropdownComponent, ModalComponent, PaginationComponent, PaginationParameters, SearchboxComponent, SelectComponent, SorterComponent, TableSelect, TableSort, TailwindComponentsModule, TailwindDirectivesModule, TailwindTablesModule, ValidationDirective, ValidationSummaryComponent, simpleFadeAnimation as ɵa, HighlightPipe as ɵb, RemovePipe as ɵc, CalendarMonthComponent as ɵd, CalendarWeekComponent as ɵe, SharedModule as ɵf, FormatDatePipe as ɵg };
//# sourceMappingURL=tailwind-lib.js.map
